==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/inbandstreams.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>InBandOptions</name>
    <message>
        <source>Packet-Query (recommended)</source>
        <translation>Paket-Abfrage (empfohlen)</translation>
    </message>
    <message>
        <source>Packet-Message</source>
        <translation>Paket-Nachricht</translation>
    </message>
</context>
<context>
    <name>InBandOptionsClass</name>
    <message>
        <source> Bytes</source>
        <translation> Bytes</translation>
    </message>
    <message>
        <source>Size of data in packet:</source>
        <translation>Größe der Daten im Paket:</translation>
    </message>
    <message>
        <source>Maximum size of data in packet:</source>
        <translation>Maximale Größe der Daten im Paket:</translation>
    </message>
    <message>
        <source>Packet type:</source>
        <translation>Paket Typ:</translation>
    </message>
</context>
<context>
    <name>InBandStream</name>
    <message>
        <source>Stream destroyed</source>
        <translation>Stream zerstört</translation>
    </message>
    <message>
        <source>Malformed data packet</source>
        <translation>Missgeformtes Daten Paket</translation>
    </message>
    <message>
        <source>Failed to open stream</source>
        <translation>Öffnen des Streams fehlgeschlagen</translation>
    </message>
    <message>
        <source>Block size is not acceptable</source>
        <translation>Block Größe nicht akzeptabel</translation>
    </message>
    <message>
        <source>Failed to send data</source>
        <translation>Daten senden fehlgeschlagen</translation>
    </message>
</context>
<context>
    <name>InBandStreams</name>
    <message>
        <source>Data is broken down into smaller chunks and transported in-band over XMPP</source>
        <translation>Daten sind in kleinere Stücke aufgeteilt und werden intern über XMPP transportiert</translation>
    </message>
    <message>
        <source>In-Band Data Stream</source>
        <translation>Interner Daten Stream</translation>
    </message>
    <message>
        <source>Allows to initiate in-band stream of data between two XMPP entities</source>
        <translation>Erlaubt das Initiieren von internen Daten Streams zwischen zwei XMPP Existenzen</translation>
    </message>
    <message>
        <source>Supports the initiating of the in-band stream of data between two XMPP entities</source>
        <translation>Unterstützt das Initiieren von internen Daten Streams zwischen zwei XMPP Existenzen</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/de/inbandstreams.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>InBandOptions</name>
    <message>
        <source>Packet-Query (recommended)</source>
        <translation>Paket-Abfrage (empfohlen)</translation>
    </message>
    <message>
        <source>Packet-Message</source>
        <translation>Paket-Nachricht</translation>
    </message>
</context>
<context>
    <name>InBandOptionsClass</name>
    <message>
        <source> Bytes</source>
        <translation> Byte</translation>
    </message>
    <message>
        <source>Size of data in packet:</source>
        <translation>Größe der Daten im Paket:</translation>
    </message>
    <message>
        <source>Maximum size of data in packet:</source>
        <translation>Maximale Größe der Daten im Paket:</translation>
    </message>
    <message>
        <source>Packet type:</source>
        <translation>Paket Typ:</translation>
    </message>
</context>
<context>
    <name>InBandStream</name>
    <message>
        <source>Stream destroyed</source>
        <translation>Datenstrom abgeschlossen</translation>
    </message>
    <message>
        <source>Malformed data packet</source>
        <translation>Fehlerhaftes Daten Paket</translation>
    </message>
    <message>
        <source>Failed to open stream</source>
        <translation>Öffnen des Datenstroms gescheitert</translation>
    </message>
    <message>
        <source>Block size is not acceptable</source>
        <translation>Block Größe nicht akzeptabel</translation>
    </message>
    <message>
        <source>Failed to send data</source>
        <translation>Senden der Daten fehlgeschlagen</translation>
    </message>
</context>
<context>
    <name>InBandStreams</name>
    <message>
        <source>Data is broken down into smaller chunks and transported in-band over XMPP</source>
        <translation>Daten sind in kleinere Stücke aufgeteilt und werden intern über XMPP transportiert</translation>
    </message>
    <message>
        <source>In-Band Data Stream</source>
        <translation>Interner Datenstrom</translation>
    </message>
    <message>
        <source>Allows to initiate in-band stream of data between two XMPP entities</source>
        <translation>Erlaubt den Aufbau von internen Datenströmen zwischen zwei XMPP Endpunkten</translation>
    </message>
    <message>
        <source>Supports the initiating of the in-band stream of data between two XMPP entities</source>
        <translation>Unterstützt den Aufbau von internen Datenströmen zwischen zwei XMPP Endpunkten</translation>
    </message>
</context>
</TS>
